@@ -173,7 +173,7 @@ CreateCaptureSocket(const char *ifName)
 //FOR MDNS IS ALWAYS CALLED WITH NULL AS SECOND ARG
 
 static int
-CreateInterface(const char *ifName, struct interface *olsrIntf)
+CreateInterface(const char *ifName, struct interface_olsr *olsrIntf)
 {
   int capturingSkfd = -1;
   int encapsulatingSkfd = -1;
@@ -310,7 +310,7 @@ CreateInterface(const char *ifName, struct interface *olsrIntf)
  * Data Used  : none
  * ------------------------------------------------------------------------- */
 int
-CreateNonOlsrNetworkInterfaces(struct interface *skipThisIntf)
+CreateNonOlsrNetworkInterfaces(struct interface_olsr *skipThisIntf)
 {
   int skfd;
   struct ifconf ifc;
@@ -355,7 +355,7 @@ CreateNonOlsrNetworkInterfaces(struct interface *skipThisIntf)
   /* For each item in the interface configuration list... */
   ifr = ifc.ifc_req;
   for (n = ifc.ifc_len / sizeof(struct ifreq); --n >= 0; ifr++) {
-    struct interface *olsrIntf;
+    struct interface_olsr *olsrIntf;
     union olsr_ip_addr ipAddr;
 
     /* Skip the BMF network interface itself */
@@ -408,7 +408,7 @@ CreateNonOlsrNetworkInterfaces(struct interface *skipThisIntf)
  * Data Used  : none
  * ------------------------------------------------------------------------- */
 void
-AddInterface(struct interface *newIntf)
+AddInterface(struct interface_olsr *newIntf)
 {
   /* int nOpened; */
 
