@@ -62,6 +62,7 @@
 #include "mpr_selector_set.h"
 #include "gateway.h"
 #include "olsr_niit.h"
+#include "olsr_random.h"
 
 #ifdef __linux__
 #include <linux/types.h>
@@ -283,28 +284,6 @@ olsrmain_load_config(char *file) {
   return 0;
 }
 
-static void initRandom(void) {
-  unsigned int seed = (unsigned int)time(NULL);
-
-#ifndef _WIN32
-  int randomFile;
-
-  randomFile = open("/dev/urandom", O_RDONLY);
-  if (randomFile == -1) {
-    randomFile = open("/dev/random", O_RDONLY);
-  }
-
-  if (randomFile != -1) {
-    if (read(randomFile, &seed, sizeof(seed)) != sizeof(seed)) {
-      ; /* to fix an 'unused result' compiler warning */
-    }
-    close(randomFile);
-  }
-#endif /* _WIN32 */
-
-  srandom(seed);
-}
-
 /**
  * Main entrypoint
  */
@@ -372,7 +351,7 @@ int main(int argc, char *argv[]) {
   olsr_openlog("olsrd");
 
   /* setup random seed */
-  initRandom();
+  olsr_init_random();
 
   /* Init widely used statics */
   memset(&all_zero, 0, sizeof(union olsr_ip_addr));
@@ -398,7 +377,7 @@ int main(int argc, char *argv[]) {
   strscpy(conf_file_name, OLSRD_GLOBAL_CONF_FILE, sizeof(conf_file_name));
 #endif /* _WIN32 */
 
-  olsr_cnf = olsrd_get_default_cnf();
+  olsr_cnf = olsrd_get_default_cnf(strdup(conf_file_name));
   for (i=1; i < argc-1;) {
     if (strcmp(argv[i], "-f") == 0) {
       loadedConfig = true;
@@ -406,6 +385,7 @@ int main(int argc, char *argv[]) {
       if (olsrmain_load_config(argv[i+1]) < 0) {
         exit(EXIT_FAILURE);
       }
+      strscpy(conf_file_name, argv[i+1], sizeof(conf_file_name));
 
       if (i+2 < argc) {
         memmove(&argv[i], &argv[i+2], sizeof(*argv) * (argc-i-1));
@@ -426,7 +406,7 @@ int main(int argc, char *argv[]) {
 
   if (!loadedConfig) {
     olsrd_free_cnf(olsr_cnf);
-    olsr_cnf = olsrd_get_default_cnf();
+    olsr_cnf = olsrd_get_default_cnf(strdup(conf_file_name));
   }
 
   default_ifcnf = get_default_if_config();
